@@ -216,47 +216,56 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 	GtkWidget *event = gtk_event_box_new ();
 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (event), FALSE);
 	self->priv->contents = gtk_vbox_new (FALSE, 0);
+	GtkWidget *bigHBox = gtk_hbox_new (TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->contents), 0);
 	GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 
-	GtkWidget *image = gtk_image_new_from_icon_name ("personal-gprs-mon", GTK_ICON_SIZE_BUTTON);
-    self->priv->titleLabel = gtk_label_new ("Dataplan Monitor");
-	hildon_helper_set_logical_font (self->priv->titleLabel, "EmpSystemFont");
-	GtkWidget *titleBox = gtk_hbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (titleBox), 0);
-	gtk_box_pack_start (GTK_BOX (titleBox), image, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (titleBox), self->priv->titleLabel, TRUE, TRUE, 0);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 1);
-	gtk_misc_set_padding (GTK_MISC (image), 2, 0);
-	gtk_misc_set_alignment (GTK_MISC (self->priv->titleLabel), 0, 0.8);
+	//GtkWidget *image = gtk_image_new_from_icon_name ("personal-gprs-mon", GTK_ICON_SIZE_BUTTON);
+    //self->priv->titleLabel = gtk_label_new ("Dataplan Monitor");
+	//hildon_helper_set_logical_font (self->priv->titleLabel, "EmpSystemFont");
+	//GtkWidget *titleBox = gtk_hbox_new (FALSE, 0);
+	//gtk_container_set_border_width (GTK_CONTAINER (titleBox), 0);
+	//gtk_box_pack_start (GTK_BOX (titleBox), image, FALSE, FALSE, 0);
+	//gtk_box_pack_start (GTK_BOX (titleBox), self->priv->titleLabel, TRUE, TRUE, 0);
+	//gtk_misc_set_alignment (GTK_MISC (image), 0.5, 1);
+	//gtk_misc_set_padding (GTK_MISC (image), 2, 0);
+	//gtk_misc_set_alignment (GTK_MISC (self->priv->titleLabel), 0, 0.8);
 	
-	self->priv->uploadLabel = gtk_label_new ("Uploaded");
-	gtk_size_group_add_widget (group, self->priv->uploadLabel);
+	//self->priv->uploadLabel = gtk_label_new ("Uploaded");
+	self->priv->uploadLabel = gtk_image_new_from_icon_name ("personal-gprs-upload", GTK_ICON_SIZE_SMALL_TOOLBAR);
+	gtk_image_set_pixel_size (GTK_IMAGE (self->priv->uploadLabel), 26);
+	//gtk_size_group_add_widget (group, self->priv->uploadLabel);
 	self->priv->uploadContent = gtk_label_new ("0.000 B");
+	gtk_label_set_markup (GTK_LABEL (self->priv->uploadContent), "0.<span gravity='north'>000</span> B");
 	GtkWidget *uploadBox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (uploadBox), self->priv->uploadLabel, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (uploadBox), self->priv->uploadContent, TRUE, TRUE, 0);
-	hildon_helper_set_logical_font (self->priv->uploadLabel, "SmallSystemFont");
-	hildon_helper_set_logical_font (self->priv->uploadContent, "SmallSystemFont");
+	//hildon_helper_set_logical_font (self->priv->uploadLabel, "SmallSystemFont");
+	//hildon_helper_set_logical_font (self->priv->uploadContent, "SmallSystemFont");
 	hildon_helper_set_logical_color (self->priv->uploadContent, GTK_RC_FG, GTK_STATE_NORMAL, "ActiveTextColor");
 	gtk_misc_set_alignment (GTK_MISC (self->priv->uploadLabel), 0, 0.5);
-	gtk_misc_set_padding (GTK_MISC (self->priv->uploadLabel), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
-	gtk_misc_set_alignment (GTK_MISC (self->priv->uploadContent), 1, 0.5);
+	//gtk_misc_set_padding (GTK_MISC (self->priv->uploadLabel), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
+	gtk_misc_set_alignment (GTK_MISC (self->priv->uploadContent), 1, 1);
 	gtk_misc_set_padding (GTK_MISC (self->priv->uploadContent), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
+	gtk_box_pack_start (GTK_BOX (bigHBox), uploadBox, TRUE, TRUE, 0);
 	
-	self->priv->downloadLabel = gtk_label_new ("Downloaded");
-	gtk_size_group_add_widget (group, self->priv->downloadLabel);
+	//self->priv->downloadLabel = gtk_label_new ("Downloaded");
+	self->priv->downloadLabel = gtk_image_new_from_icon_name ("personal-gprs-download", GTK_ICON_SIZE_SMALL_TOOLBAR);
+	gtk_image_set_pixel_size (GTK_IMAGE (self->priv->downloadLabel), 26);
+	//gtk_size_group_add_widget (group, self->priv->downloadLabel);
 	self->priv->downloadContent = gtk_label_new ("0.000 B");
+	gtk_label_set_markup (GTK_LABEL (self->priv->downloadContent), "0.<span gravity='north'>000</span> B");
 	GtkWidget *downloadBox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (downloadBox), self->priv->downloadLabel, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (downloadBox), self->priv->downloadContent, TRUE, TRUE, 0);	
-	hildon_helper_set_logical_font (self->priv->downloadLabel, "SmallSystemFont");
-	hildon_helper_set_logical_font (self->priv->downloadContent, "SmallSystemFont");
+	//hildon_helper_set_logical_font (self->priv->downloadLabel, "SmallSystemFont");
+	//hildon_helper_set_logical_font (self->priv->downloadContent, "SmallSystemFont");
 	hildon_helper_set_logical_color (self->priv->downloadContent, GTK_RC_FG, GTK_STATE_NORMAL, "ActiveTextColor");
 	gtk_misc_set_alignment (GTK_MISC (self->priv->downloadLabel), 0, 0.5);
-	gtk_misc_set_padding (GTK_MISC (self->priv->downloadLabel), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
-	gtk_misc_set_alignment (GTK_MISC (self->priv->downloadContent), 1, 0.5);
+	//gtk_misc_set_padding (GTK_MISC (self->priv->downloadLabel), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
+	gtk_misc_set_alignment (GTK_MISC (self->priv->downloadContent), 1, 1);
 	gtk_misc_set_padding (GTK_MISC (self->priv->downloadContent), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
+	gtk_box_pack_start (GTK_BOX (bigHBox), downloadBox, TRUE, TRUE, 0);
 	
 	self->priv->resetLabel = gtk_label_new ("Last Reset");
 	gtk_size_group_add_widget (group, self->priv->resetLabel);
@@ -272,9 +281,9 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 	gtk_misc_set_alignment (GTK_MISC (self->priv->resetContent), 1, 0.5);
 	gtk_misc_set_padding (GTK_MISC (self->priv->resetContent), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
 	
-	gtk_box_pack_start (GTK_BOX (self->priv->contents), titleBox, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (self->priv->contents), uploadBox, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (self->priv->contents), downloadBox, FALSE, FALSE, 0);	
+	//gtk_box_pack_start (GTK_BOX (self->priv->contents), titleBox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (self->priv->contents), bigHBox, FALSE, FALSE, 0);
+	//gtk_box_pack_start (GTK_BOX (self->priv->contents), downloadBox, FALSE, FALSE, 0);	
 	gtk_box_pack_start (GTK_BOX (self->priv->contents), self->priv->resetBox, FALSE, FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (event), self->priv->contents);
     gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), event, FALSE, FALSE, 0);
@@ -337,58 +346,58 @@ gboolean personal_gprs_mon_update_content (PersonalGprsMon *self)
 	if (self->priv->binaryPrefix) {
 		if (upload > 1024 && upload <= 1048576) {
 			uploadSize = upload / 1024.0;
-			uploadUnits = " KiB";
+			uploadUnits = "KiB";
 		} else if (upload > 1048576 && upload <= 1073741824) {
 			uploadSize = upload / 1048576.0;
-			uploadUnits = " MiB";
+			uploadUnits = "MiB";
 		} else if (upload > 1073741824) {
 			uploadSize = upload / 1073741824.0;
-			uploadUnits = " GiB";
+			uploadUnits = "GiB";
 		} else {
 			uploadSize = upload / 1.0;
-			uploadUnits = " B";
+			uploadUnits = "B";
 		}
 		
 		if (download > 1024 && download <= 1048576) {
 			downloadSize = download / 1024.0;
-			downloadUnits = " KiB";
+			downloadUnits = "KiB";
 		} else if (download > 1048576 && download <= 1073741824) {
 			downloadSize = download / 1048576.0;
-			downloadUnits = " MiB";
+			downloadUnits = "MiB";
 		} else if (download > 1073741824) {
 			downloadSize = download / 1073741824.0;
-			downloadUnits = " GiB";
+			downloadUnits = "GiB";
 		} else {
 			downloadSize = download / 1.0;
-			downloadUnits = " B";
+			downloadUnits = "B";
 		}
 	} else {
 		if (upload > 1000 && upload <= 1000000) {
 			uploadSize = upload / 1000.0;
-			uploadUnits = " kB";
+			uploadUnits = "kB";
 		} else if (upload > 1000000 && upload <= 1000000000) {
 			uploadSize = upload / 1000000.0;
-			uploadUnits = " MB";
+			uploadUnits = "MB";
 		} else if (upload > 1000000000) {
 			uploadSize = upload / 1000000000.0;
-			uploadUnits = " GB";
+			uploadUnits = "GB";
 		} else {
 			uploadSize = upload /1.0;
-			uploadUnits = " B";
+			uploadUnits = "B";
 		}
 		
 		if (download > 1000 && download <= 1000000) {
 			downloadSize = download / 1000.0;
-			downloadUnits = " kB";
+			downloadUnits = "kB";
 		} else if (download > 1000000 && download <= 1000000000) {
 			downloadSize = download / 1000000.0;
-			downloadUnits = " MB";
-		} else if (upload > 1000000000) {
+			downloadUnits = "MB";
+		} else if (download > 1000000000) {
 			downloadSize = download / 1000000000.0;
-			downloadUnits = " GB";
+			downloadUnits = "GB";
 		} else {
 			downloadSize = download / 1.0;
-			downloadUnits = " B";
+			downloadUnits = "B";
 		}
 	}
 	
@@ -405,17 +414,24 @@ gboolean personal_gprs_mon_update_content (PersonalGprsMon *self)
 		gtk_label_set_text (GTK_LABEL (self->priv->resetContent), dateString);
 	}
 	
-	gtk_label_set_text (GTK_LABEL (self->priv->uploadContent), g_strconcat (g_strdup_printf ("%.3f", uploadSize), uploadUnits, NULL));
-	gtk_label_set_text (GTK_LABEL (self->priv->downloadContent), g_strconcat (g_strdup_printf ("%.3f", downloadSize), downloadUnits, NULL));
+	gint uploadInt = (gint) uploadSize;
+	gint downloadInt = (gint) downloadSize;
+	gint uploadRemainder = (gint) ((uploadSize - uploadInt) * pow (10, 3));
+	gint downloadRemainder = (gint) ((downloadSize - downloadInt) * pow (10, 3));
+	gtk_label_set_text (GTK_LABEL (self->priv->uploadContent), g_strdup_printf ("%d.%03d %s", uploadInt, uploadRemainder, uploadUnits));
+	gtk_label_set_markup (GTK_LABEL (self->priv->uploadContent), g_strdup_printf ("%d.<small><sup>%03d</sup></small> %s", uploadInt, uploadRemainder, uploadUnits));
+	gtk_label_set_text (GTK_LABEL (self->priv->downloadContent), g_strdup_printf ("%d.%03d %s", downloadInt, downloadRemainder, downloadUnits));
+	gtk_label_set_markup (GTK_LABEL (self->priv->downloadContent), g_strdup_printf ("%d.<small><sup>%03d</sup></small> %s", downloadInt, downloadRemainder, downloadUnits));
+
 	
 	if (self->priv->showResetDate) {
 		gtk_widget_show_all (self->priv->resetBox);
-		gtk_widget_set_size_request (GTK_WIDGET (self), 315, 155);
-		gtk_window_resize (GTK_WINDOW (self), 315, 155);
+		gtk_widget_set_size_request (GTK_WIDGET (self), 315, 75);
+		gtk_window_resize (GTK_WINDOW (self), 315, 75);
 	} else {
 		gtk_widget_hide (self->priv->resetBox);
-		gtk_widget_set_size_request (GTK_WIDGET (self), 315, 120);
-		gtk_window_resize (GTK_WINDOW (self), 315, 120);
+		gtk_widget_set_size_request (GTK_WIDGET (self), 315, 40);
+		gtk_window_resize (GTK_WINDOW (self), 315, 40);
 	}
 		
 	return TRUE;
@@ -580,7 +596,7 @@ static gboolean personal_gprs_mon_expose_event (GtkWidget *widget, GdkEventExpos
 	GdkColor color;
 	if (!self->priv->isPressed) {
 		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.75);
 	} else {
 		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
 		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
@@ -588,59 +604,27 @@ static gboolean personal_gprs_mon_expose_event (GtkWidget *widget, GdkEventExpos
 	
 	gint width, height, x, y;
 	gint radius = 5;
-	gint iconOffset = 16;
-	gint iconSize = 56;
 	width = widget->allocation.width;
-	height = iconSize - iconOffset;
+	height = widget->allocation.height;
 	x = widget->allocation.x;
-	y = widget->allocation.y + iconOffset;
+	y = widget->allocation.y;
 
 	cairo_move_to(cr, x + radius, y);
 	cairo_line_to(cr, x + width - radius, y);
 	cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
 				y + radius);
-	cairo_line_to(cr, x + width, y + height);
-	cairo_curve_to(cr, x + width, y + height, x + width,
-				y + height, x + width, y + height);
-	cairo_line_to(cr, x, y + height);
-	cairo_curve_to(cr, x, y + height, x, y + height, x,
-				y + height);
-	cairo_line_to(cr, x, y);
-	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
-
-	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-
-	cairo_fill_preserve(cr);
-	
-	gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
-	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
-	cairo_set_line_width (cr, 1);
-	cairo_stroke (cr);
-	
-	width = widget->allocation.width;
-	height = widget->allocation.height - iconSize;
-	x = widget->allocation.x;
-	y = iconSize;
-	
-	if (!self->priv->isPressed) {
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
-	} else {
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
-	}
-
-	cairo_move_to(cr, x + radius, y);
-	cairo_line_to(cr, x + width, y);
 	cairo_line_to(cr, x + width, y + height - radius);
 	cairo_curve_to(cr, x + width, y + height - radius, x + width,
 				y + height, x + width - radius, y + height);
 	cairo_line_to(cr, x + radius, y + height);
 	cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
 				y + height - radius);
-	cairo_line_to(cr, x, y);
+	cairo_line_to(cr, x, y + radius);
+	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
 
-	cairo_fill_preserve (cr);
+	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+
+	cairo_fill_preserve(cr);
 	
 	gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
 	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
@@ -681,7 +665,7 @@ static void personal_gprs_mon_init (PersonalGprsMon *self)
 	hd_home_plugin_item_set_settings (&self->parent, TRUE);
 	g_signal_connect (&self->parent, "show-settings", G_CALLBACK (personal_gprs_mon_settings), self);
 
-	gtk_window_set_default_size (GTK_WINDOW (self), 315, 120);
+	gtk_window_set_default_size (GTK_WINDOW (self), 315, 40);
 	
 	self->priv->homeWidget = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (self), self->priv->homeWidget);
@@ -689,9 +673,9 @@ static void personal_gprs_mon_init (PersonalGprsMon *self)
 
 	GdkGeometry hints;
 	hints.min_width = 315;
-	hints.min_height = 120;
+	hints.min_height = 40;
 	hints.max_width = 315;
-	hints.max_height = 155;
+	hints.max_height = 75;
 	gtk_window_set_geometry_hints (GTK_WINDOW (self), self->priv->homeWidget, &hints, GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
 	
 	g_type_init ();
